@@ -3,7 +3,6 @@ import sys
 import re
 from optparse import OptionParser
 from pythonbrew import commands
-from pythonbrew.define import PATH_BIN_PYTHONBREW
 
 command_dict = {}
 
@@ -14,12 +13,12 @@ class Command(object):
     
     def __init__(self):
         self.parser = OptionParser(usage=self.usage,
-                                   prog='%s %s' % (PATH_BIN_PYTHONBREW, self.name))
+                                   prog='%s %s' % ("pythonbrew", self.name))
         command_dict[self.name] = self
         
     def run(self, args):
         options, args = self.parser.parse_args(args)
-        self.run_command(options, args[1:])
+        self.run_command(options, args)
 
 def load_command(name):
     full_name = 'pythonbrew.commands.%s' % name
